//-*-c++-*-
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "tulip/MetaGraph.h"
#include "tulip/SuperGraph.h"
#include "tulip/MetaGraphProxy.h"

MetaGraph::MetaGraph (const PropertyContext &context):Property<MetaGraphType , MetaGraphType>(context) {
  metaGraphProxy=(MetaGraphProxy *)context.propertyProxy;
}
